(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     18463,        484]
NotebookOptionsPosition[     17324,        441]
NotebookOutlinePosition[     17959,        465]
CellTagsIndexPosition[     17916,        462]
WindowFrame->Normal
ContainsDynamic->True *)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Image Compression via the Fourier Transform", "Section",
 CellFrameColor->RGBColor[
  0.6449835965514611, 0.758632791638056, 0.2516823071641108],
 FontColor->RGBColor[
  0.6449835965514611, 0.758632791638056, 0.2516823071641108]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"cf", ",", "if"}], "}"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"cf", " ", "=", " ", 
       RowBox[{"Chop", "[", 
        RowBox[{"flena", ",", 
         RowBox[{"10", "^", 
          RowBox[{"Chop", "[", "c", "]"}]}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"if", " ", "=", " ", 
       RowBox[{"InverseFourier", "[", "cf", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Grid", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Text", "@", 
            RowBox[{"Row", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Style", "[", 
                RowBox[{"\"\<original (\>\"", ",", "\"\<Label\>\""}], "]"}], 
               ",", 
               RowBox[{"Times", "@@", 
                RowBox[{"Dimensions", "[", "lena", "]"}]}], ",", 
               "\"\< bytes)\>\""}], "}"}], "]"}]}], ",", 
           RowBox[{"Text", "@", 
            RowBox[{"Row", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Style", "[", 
                RowBox[{"\"\<compressed (\>\"", ",", "\"\<Label\>\""}], "]"}],
                ",", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"Times", "@@", 
                  RowBox[{"Dimensions", "[", "lena", "]"}]}], ")"}], "-", 
                RowBox[{"Count", "[", 
                 RowBox[{"cf", ",", "0", ",", 
                  RowBox[{"{", "2", "}"}]}], "]"}]}], ",", 
               "\"\< bytes)\>\""}], "}"}], "]"}]}]}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"lenaplot", ",", 
           RowBox[{"ArrayPlot", "[", 
            RowBox[{"if", ",", 
             RowBox[{"ImageSize", "\[Rule]", "200"}], ",", 
             RowBox[{"PlotRangePadding", "\[Rule]", "None"}], ",", 
             RowBox[{"Frame", "\[Rule]", "False"}]}], "]"}]}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Text", "@", 
            RowBox[{"Style", "[", 
             RowBox[{"\"\<error\>\"", ",", "\"\<Label\>\""}], "]"}]}], ",", 
           RowBox[{"Text", "@", 
            RowBox[{"Style", "[", 
             RowBox[{"str", ",", "\"\<Label\>\""}], "]"}]}]}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"ArrayPlot", "[", 
            RowBox[{
             RowBox[{"Abs", "[", 
              RowBox[{"lena", " ", "-", " ", "if"}], "]"}], ",", 
             RowBox[{"ImageSize", "\[Rule]", "200"}], ",", 
             RowBox[{"PlotRangePadding", "\[Rule]", "None"}], ",", 
             RowBox[{"Frame", "\[Rule]", "False"}]}], "]"}], ",", 
           RowBox[{"ArrayPlot", "[", 
            RowBox[{
             RowBox[{"RotateRight", "[", 
              RowBox[{
               RowBox[{"switch", "[", 
                RowBox[{"str", ",", "cf"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"128", ",", "128"}], "}"}]}], "]"}], ",", 
             RowBox[{"ImageSize", "\[Rule]", "200"}], ",", 
             RowBox[{"PlotRangePadding", "\[Rule]", "None"}], ",", 
             RowBox[{"Frame", "\[Rule]", "False"}]}], "]"}]}], "}"}]}], "}"}],
        "]"}]}]}], "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"c", ",", 
       RowBox[{"-", "3"}], ",", "\"\<compression\>\""}], "}"}], ",", 
     RowBox[{"-", "3"}], ",", "3", ",", ".1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "str", ",", "\"\<power spectrum\>\"", ",", 
       "\"\<spectrum selection\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\"\<power spectrum\>\"", ",", "\"\<phase spectrum\>\""}], 
      "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", " ", "PopupMenu"}]}], "}"}], ",", 
   RowBox[{"Initialization", "\[RuleDelayed]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"lena", " ", "=", 
       RowBox[{"Transpose", "@", 
        RowBox[{"Take", "[", 
         RowBox[{
          RowBox[{"Transpose", "[", 
           RowBox[{"Take", "[", 
            RowBox[{
             RowBox[{"N", "@", 
              RowBox[{"Map", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"255", "-", 
                  RowBox[{"Mean", "[", "#", "]"}]}], "&"}], ",", 
                RowBox[{"ExampleData", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"\"\<TestImage\>\"", ",", "\"\<Lena\>\""}], "}"}], 
                  ",", "\"\<Data\>\""}], "]"}], ",", 
                RowBox[{"{", "2", "}"}]}], "]"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"200", ",", "300"}], "}"}]}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"250", ",", "350"}], "}"}]}], "]"}]}]}], ";", "\n", 
      RowBox[{
       RowBox[{"switch", "[", 
        RowBox[{"str_", ",", "x_"}], "]"}], ":=", " ", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"str", " ", "===", " ", "\"\<power spectrum\>\""}], ",", 
         RowBox[{"Sqrt", "[", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"Abs", "[", "x", "]"}], "]"}], "]"}], ",", 
         RowBox[{"Arg", "[", "x", "]"}]}], "]"}]}], ";", "\n", 
      RowBox[{"lenaplot", " ", ":=", 
       RowBox[{"ArrayPlot", "[", 
        RowBox[{"lena", ",", 
         RowBox[{"ImageSize", "\[Rule]", "200"}], ",", 
         RowBox[{"PlotRangePadding", "\[Rule]", "None"}], ",", 
         RowBox[{"Frame", "\[Rule]", "False"}]}], "]"}]}], ";", "\n", 
      RowBox[{"flena", ":=", 
       RowBox[{"Fourier", "[", 
        RowBox[{"N", "[", "lena", "]"}], "]"}]}], ";"}], "}"}]}], ",", 
   RowBox[{"SynchronousInitialization", "\[Rule]", "False"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{
  3.35696210375764*^9, {3.36276326180215*^9, 3.36276338813683*^9}, {
   3.36276416706492*^9, 3.36276419105613*^9}, {3.36276424238389*^9, 
   3.36276434757247*^9}, {3.36276438165713*^9, 3.36276455793354*^9}, {
   3.36276459273154*^9, 3.36276464460369*^9}, {3.36276472675827*^9, 
   3.36276486967973*^9}, {3.36276489975277*^9, 3.36276491336111*^9}, {
   3.36276503188569*^9, 3.36276504138537*^9}, {3.36276509673442*^9, 
   3.36276516154717*^9}, {3.36276554326288*^9, 3.36276562579235*^9}, {
   3.36276576059363*^9, 3.36276579593328*^9}, {3.36276582890284*^9, 
   3.36276583247754*^9}, {3.36276686957212*^9, 3.36276688984583*^9}, {
   3.36276692403946*^9, 3.3627669264598*^9}, {3.36276720662416*^9, 
   3.36276720885642*^9}, {3.36276724403545*^9, 3.36276724600828*^9}, {
   3.36276731976605*^9, 3.36276732908766*^9}, {3.36276737337609*^9, 
   3.36276737455723*^9}, {3.36284013610226*^9, 3.36284028966789*^9}, {
   3.36284418095676*^9, 3.36284419386056*^9}, {3.36284438093726*^9, 
   3.36284438178298*^9}, {3.36284456126995*^9, 3.36284456407787*^9}, {
   3.36284496601625*^9, 3.36284496690851*^9}, {3.36293248362745*^9, 
   3.36293255901667*^9}, {3.36293284329704*^9, 3.36293284606083*^9}, {
   3.36965562953125*^9, 3.369655639796875*^9}, {3.3709750180075808`*^9, 
   3.3709750183357563`*^9}, {3.3709751424641943`*^9, 
   3.3709751702028294`*^9}, {3.370975237072474*^9, 3.37097524623013*^9}, {
   3.370975618099741*^9, 3.370975643150463*^9}, {3.370975686719654*^9, 
   3.3709756887199616`*^9}, {3.3709763773882246`*^9, 3.370976381185683*^9}, {
   3.3709768148147783`*^9, 3.3709768173776717`*^9}, {3.380397234140625*^9, 
   3.38039723609375*^9}, {3.380398458171875*^9, 3.380398475*^9}, {
   3.38039932840625*^9, 3.380399329359375*^9}, {3.3803994886875*^9, 
   3.380399498921875*^9}, 3.380401895203125*^9, {3.382190299259033*^9, 
   3.382190301540283*^9}, 3.382190334024658*^9, {3.3853054363620443`*^9, 
   3.3853054827057943`*^9}, {3.3853055959714193`*^9, 
   3.3853056130495443`*^9}, {3.3853058388464193`*^9, 
   3.3853058621276693`*^9}, {3.3853062301432943`*^9, 3.3853063580964193`*^9}},
 
 CellID->854742232],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`c$$ = -3, $CellContext`str$$ = 
    "power spectrum", Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`c$$], -3, "compression"}, -3, 3, 0.1}, {{
       Hold[$CellContext`str$$], "power spectrum", "spectrum selection"}, {
      "power spectrum", "phase spectrum"}}}, Typeset`size$$ = {
    408., {216.875, 222.125}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`c$871142$$ = 
    0, $CellContext`str$871143$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`c$$ = -3, $CellContext`str$$ = 
        "power spectrum"}, "ControllerVariables" :> {
        Hold[$CellContext`c$$, $CellContext`c$871142$$, 0], 
        Hold[$CellContext`str$$, $CellContext`str$871143$$, False]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`cf$, $CellContext`if$}, $CellContext`cf$ = 
         Chop[$CellContext`flena, 10^
           Chop[$CellContext`c$$]]; $CellContext`if$ = 
         InverseFourier[$CellContext`cf$]; Grid[{{
            Text[
             Row[{
               Style["original (", "Label"], 
               Apply[Times, 
                Dimensions[$CellContext`lena]], " bytes)"}]], 
            Text[
             Row[{
               Style["compressed (", "Label"], Apply[Times, 
                 Dimensions[$CellContext`lena]] - 
               Count[$CellContext`cf$, 0, {2}], 
               " bytes)"}]]}, {$CellContext`lenaplot, 
            
            ArrayPlot[$CellContext`if$, ImageSize -> 200, PlotRangePadding -> 
             None, Frame -> False]}, {
            Text[
             Style["error", "Label"]], 
            Text[
             Style[$CellContext`str$$, "Label"]]}, {
            ArrayPlot[
             Abs[$CellContext`lena - $CellContext`if$], ImageSize -> 200, 
             PlotRangePadding -> None, Frame -> False], 
            ArrayPlot[
             RotateRight[
              $CellContext`switch[$CellContext`str$$, $CellContext`cf$], {128,
               128}], ImageSize -> 200, PlotRangePadding -> None, Frame -> 
             False]}}]], 
      "Specifications" :> {{{$CellContext`c$$, -3, "compression"}, -3, 3, 
         0.1}, {{$CellContext`str$$, "power spectrum", 
          "spectrum selection"}, {"power spectrum", "phase spectrum"}, 
         ControlType -> PopupMenu}}, 
      "Options" :> {SynchronousInitialization -> False}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{450., {274.375, 279.625}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`lena = Transpose[
          Take[
           Transpose[
            Take[
             N[
              Map[255 - Mean[#]& , 
               ExampleData[{"TestImage", "Lena"}, "Data"], {2}]], {200, 
             300}]], {250, 350}]]; $CellContext`switch[
          Pattern[$CellContext`str, 
           Blank[]], 
          Pattern[$CellContext`x, 
           Blank[]]] := If[$CellContext`str === "power spectrum", 
          Sqrt[
           Sqrt[
            Abs[$CellContext`x]]], 
          Arg[$CellContext`x]]; $CellContext`lenaplot := 
        ArrayPlot[$CellContext`lena, ImageSize -> 200, PlotRangePadding -> 
          None, Frame -> False]; $CellContext`flena := Fourier[
          N[$CellContext`lena]]; Null}; Typeset`initDone$$ = True),
    SynchronousInitialization->False,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellID->722290185]
}, {2}]]
}, Open  ]],

Cell[CellGroupData[{

Cell["THIS NOTEBOOK IS THE SOURCE CODE FROM", "Text",
 CellFrame->{{0, 0}, {0, 1}},
 CellMargins->{{48, 10}, {4, 28}},
 CellGroupingRules->{"SectionGrouping", 25},
 CellFrameMargins->{{48, 48}, {6, 5}},
 CellFrameColor->RGBColor[0.691905, 0.790311, 0.300252],
 FontFamily->"Helvetica",
 FontSize->10,
 FontWeight->"Bold",
 FontColor->RGBColor[0.691905, 0.790311, 0.300252]],

Cell[TextData[{
 "\"",
 ButtonBox["Image Compression via the Fourier Transform",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/\
ImageCompressionViaTheFourierTransform/"], None},
  ButtonNote->
   "http://demonstrations.wolfram.com/ImageCompressionViaTheFourierTransform/\
"],
 "\"",
 " from ",
 ButtonBox["The Wolfram Demonstrations Project",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/"], None},
  ButtonNote->"http://demonstrations.wolfram.com/"],
 "\[ParagraphSeparator]\[NonBreakingSpace]",
 ButtonBox["http://demonstrations.wolfram.com/\
ImageCompressionViaTheFourierTransform/",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/\
ImageCompressionViaTheFourierTransform/"], None},
  ButtonNote->
   "http://demonstrations.wolfram.com/ImageCompressionViaTheFourierTransform/\
"]
}], "Text",
 CellMargins->{{48, Inherited}, {0, Inherited}},
 FontFamily->"Verdana",
 FontSize->10,
 FontColor->GrayLevel[0.5]]
}, Open  ]],

Cell[CellGroupData[{

Cell[" ", "Text",
 CellFrame->{{0, 0}, {0, 1}},
 CellMargins->{{48, 10}, {4, 28}},
 CellGroupingRules->{"SectionGrouping", 25},
 CellFrameMargins->{{48, 48}, {6, 5}},
 CellFrameColor->RGBColor[0.691905, 0.790311, 0.300252],
 FontFamily->"Helvetica",
 FontSize->10,
 FontWeight->"Bold",
 FontColor->RGBColor[0.691905, 0.790311, 0.300252]],

Cell["Contributed by: Chris Maes", "Text",
 CellDingbat->"\[FilledSmallSquare]",
 CellMargins->{{66, 48}, {2, 4}},
 FontFamily->"Verdana",
 FontSize->10,
 FontColor->GrayLevel[0.6],
 CellID->1121372264],

Cell[TextData[{
 "A full-function Wolfram ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 6 system is required to edit or run this notebook.\[IndentingNewLine](",
 StyleBox["Mathematica Player",
  FontSlant->"Italic"],
 " runs only Demonstrations published on this site.)\n",
 StyleBox[ButtonBox["GET WOLFRAM MATHEMATICA 6 \[RightGuillemet]",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/products/mathematica/"], None},
  ButtonNote->"http://www.wolfram.com/products/mathematica/"],
  FontFamily->"Helvetica",
  FontWeight->"Bold",
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0.42, 0]]
}], "Text",
 CellFrame->True,
 CellMargins->{{48, 68}, {8, 28}},
 CellFrameMargins->12,
 CellFrameColor->RGBColor[0.865507, 0.90634, 0.680751],
 CellChangeTimes->{3.3750111182355957`*^9},
 ParagraphSpacing->{1., 1.},
 FontFamily->"Verdana",
 FontSize->10,
 FontColor->GrayLevel[0.411765],
 Background->RGBColor[0.986023, 0.991363, 0.969818]],

Cell[TextData[{
 "\[Copyright] ",
 StyleBox[ButtonBox["The Wolfram Demonstrations Project & Contributors",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/"], None},
  ButtonNote->"http://demonstrations.wolfram.com/"],
  FontColor->GrayLevel[0.6]],
 "\[ThickSpace]\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
 StyleBox[ButtonBox["Terms of Use",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/termsofuse.html"], None},
  ButtonNote->"http://demonstrations.wolfram.com/termsofuse.html"],
  FontColor->GrayLevel[0.6]],
 "\[ThickSpace]\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
 StyleBox[ButtonBox["Make a new version of this Demonstration \
\[RightGuillemet]",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/participate/upload.jsp?id=\
ImageCompressionViaTheFourierTransform"], None},
  ButtonNote->None],
  FontColor->GrayLevel[0.6]]
}], "Text",
 CellFrame->{{0, 0}, {0, 0.5}},
 CellMargins->{{48, 10}, {20, 50}},
 CellFrameMargins->{{6, 0}, {6, 6}},
 CellFrameColor->GrayLevel[0.6],
 FontFamily->"Verdana",
 FontSize->9,
 FontColor->GrayLevel[0.6]]
}, Open  ]]
},
ClosingSaveDialog->False,
Editable->True,
ScreenStyleEnvironment->"Working",
WindowSize->{710, 650},
WindowMargins->{{Inherited, Inherited}, {Inherited, 0}},
WindowElements->{
 "StatusArea", "MemoryMonitor", "MagnificationPopUp", "VerticalScrollBar", 
  "MenuBar"},
WindowTitle->"Image Compression via the Fourier Transform - Source",
DockedCells->{},
CellContext->Notebook,
FrontEndVersion->"6.0 for Mac OS X x86 (32-bit) (May 22, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 235, 4, 67, "Section"],
Cell[CellGroupData[{
Cell[850, 31, 8112, 182, 70, "Input",
 CellID->854742232],
Cell[8965, 215, 4127, 89, 572, "Output",
 CellID->722290185]
}, {2}]]
}, Open  ]],
Cell[CellGroupData[{
Cell[13138, 310, 373, 9, 50, "Text",
 CellGroupingRules->{"SectionGrouping", 25}],
Cell[13514, 321, 1028, 31, 34, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14579, 357, 337, 9, 70, "Text",
 CellGroupingRules->{"SectionGrouping", 25}],
Cell[14919, 368, 202, 6, 70, "Text",
 CellID->1121372264],
Cell[15124, 376, 967, 27, 70, "Text"],
Cell[16094, 405, 1214, 33, 70, "Text"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

