(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     25164,        653]
NotebookOptionsPosition[     23978,        608]
NotebookOutlinePosition[     24601,        632]
CellTagsIndexPosition[     24558,        629]
WindowFrame->Normal
ContainsDynamic->True *)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Probabilistic Forest Fire Model", "Section",
 CellFrameColor->RGBColor[
  0.6449835965514611, 0.758632791638056, 0.2516823071641108],
 FontColor->RGBColor[
  0.6449835965514611, 0.758632791638056, 0.2516823071641108]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"DynamicModule", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"SeedRandom", "[", "1", "]"}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"iteration", ":=", 
       RowBox[{"Module", "[", 
        RowBox[{
         RowBox[{"{", "}"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"trees", "[", 
                RowBox[{"[", 
                 RowBox[{"Sequence", "@@", "#"}], "]"}], "]"}], "=", 
               RowBox[{"RandomChoice", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"staylit", ",", 
                   RowBox[{"1", "-", "staylit"}]}], "}"}], "->", 
                 RowBox[{"{", 
                  RowBox[{"1", ",", "2"}], "}"}]}], "]"}]}], ")"}], ";"}], 
            "&"}], "/@", 
           RowBox[{"Position", "[", 
            RowBox[{"trees", ",", "1"}], "]"}]}], ";", "\[IndentingNewLine]", 
          
          RowBox[{
           RowBox[{
            RowBox[{"Do", "[", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"Which", "[", "\[IndentingNewLine]", 
               RowBox[{"(*", " ", 
                RowBox[{
                 RowBox[{"don", "'"}], "t", " ", "do", " ", "anything", " ", 
                 "at", " ", "the", " ", "boundary"}], " ", "*)"}], 
               "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"MemberQ", "[", 
                 RowBox[{
                  RowBox[{"#", "+", "i"}], ",", 
                  RowBox[{"0", "|", "101"}]}], "]"}], ",", 
                "\[IndentingNewLine]", "Null", ",", "\[IndentingNewLine]", 
                "\[IndentingNewLine]", 
                RowBox[{"(*", " ", 
                 RowBox[{
                 "only", " ", "ignite", " ", "unburnt", " ", "trees"}], " ", 
                 "*)"}], "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"trees", "[", 
                  RowBox[{"[", 
                   RowBox[{"Sequence", "@@", 
                    RowBox[{"(", 
                    RowBox[{"#", "+", "i"}], ")"}]}], "]"}], "]"}], 
                 "\[Equal]", "0"}], ",", 
                RowBox[{
                 RowBox[{"trees", "[", 
                  RowBox[{"[", 
                   RowBox[{"Sequence", "@@", 
                    RowBox[{"(", 
                    RowBox[{"#", "+", "i"}], ")"}]}], "]"}], "]"}], "=", 
                 RowBox[{"RandomChoice", "[", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"1", "-", "ignite"}], ",", "ignite"}], "}"}], "->",
                    
                   RowBox[{"{", 
                    RowBox[{"0", ",", "1"}], "}"}]}], "]"}]}]}], 
               "\[IndentingNewLine]", "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", 
                RowBox[{"DeleteCases", "[", 
                 RowBox[{
                  RowBox[{"Tuples", "[", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "1"}], ",", "0", ",", "1"}], "}"}], ",", 
                    "2"}], "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}]}], "]"}]}], "}"}]}], "]"}], 
            ";", "&"}], "/@", 
           RowBox[{"Position", "[", 
            RowBox[{"trees", ",", "1"}], "]"}]}]}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"Dynamic", "[", 
       RowBox[{"Graphics", "[", 
        RowBox[{
         RowBox[{"Raster", "[", 
          RowBox[{"Developer`ToPackedArray", "[", 
           RowBox[{"trees", "/.", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"0", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{"0.", ",", ".6", ",", "0."}], "}"}]}], ",", 
              RowBox[{"1", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{"1.", ",", ".2", ",", "0."}], "}"}]}], ",", 
              RowBox[{"2", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{".8", ",", ".8", ",", ".8"}], "}"}]}]}], "}"}]}], 
           "]"}], "]"}], ",", 
         RowBox[{"ImageSize", "\[Rule]", "400"}], ",", 
         RowBox[{"PlotLabel", "\[Rule]", 
          RowBox[{"Style", "[", 
           RowBox[{
            RowBox[{"Column", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Row", "[", 
                RowBox[{"{", 
                 RowBox[{"\"\<not burned: \>\"", ",", "\[IndentingNewLine]", 
                  RowBox[{"NumberForm", "[", 
                   RowBox[{
                    RowBox[{"Round", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"Count", "[", 
                    RowBox[{
                    RowBox[{"Flatten", "[", "trees", "]"}], ",", "0"}], "]"}],
                     "/", "100"}], "//", "N"}], ",", ".01"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"4", ",", "2"}], "}"}], ",", 
                    RowBox[{"NumberPadding", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"\"\< \>\"", ",", "\"\<0\>\""}], "}"}]}]}], "]"}],
                   ",", "\"\<%\>\""}], "}"}], "]"}], ",", 
               RowBox[{"Row", "[", 
                RowBox[{"{", 
                 RowBox[{"\"\<on fire:         \>\"", ",", 
                  RowBox[{"NumberForm", "[", 
                   RowBox[{
                    RowBox[{"Round", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"Count", "[", 
                    RowBox[{
                    RowBox[{"Flatten", "[", "trees", "]"}], ",", "1"}], "]"}],
                     "/", "100"}], "//", "N"}], ",", ".01"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"4", ",", "2"}], "}"}], ",", 
                    RowBox[{"NumberPadding", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"\"\< \>\"", ",", "\"\<0\>\""}], "}"}]}]}], "]"}],
                   ",", "\"\<%\>\""}], "}"}], "]"}], ",", 
               RowBox[{"Row", "[", 
                RowBox[{"{", 
                 RowBox[{"\"\<burned:       \>\"", ",", 
                  RowBox[{"NumberForm", "[", 
                   RowBox[{
                    RowBox[{"Round", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"Count", "[", 
                    RowBox[{
                    RowBox[{"Flatten", "[", "trees", "]"}], ",", "2"}], "]"}],
                     "/", "100"}], "//", "N"}], ",", ".01"}], "]"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"4", ",", "2"}], "}"}], ",", 
                    RowBox[{"NumberPadding", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"\"\< \>\"", ",", "\"\<0\>\""}], "}"}]}]}], "]"}],
                   ",", "\"\<%\>\""}], "}"}], "]"}]}], "}"}], "]"}], ",", 
            "\"\<Label\>\"", ",", "12"}], "]"}]}], ",", 
         RowBox[{"PlotRange", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "100"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "100"}], "}"}]}], "}"}]}]}], "]"}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"ignite", ",", ".7", ",", "\"\<chance to catch on fire\>\""}], 
      "}"}], ",", ".1", ",", ".9", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"staylit", ",", ".45", ",", "\"\<chance to stay on fire\>\""}], 
      "}"}], ",", ".1", ",", ".9", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"run", ",", 
     RowBox[{
      RowBox[{"Row", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Animator", "[", 
          RowBox[{
           RowBox[{"Dynamic", "[", 
            RowBox[{"run", ",", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"iteration", ";", 
                RowBox[{"run", "=", "#"}]}], ")"}], "&"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "Infinity", ",", "1"}], "}"}], ",", 
           RowBox[{"AppearanceElements", "\[Rule]", 
            RowBox[{"{", "\"\<PlayPauseButton\>\"", "}"}]}], ",", 
           RowBox[{"DisplayAllSteps", "\[Rule]", "True"}], ",", 
           RowBox[{"AnimationRepetitions", "\[Rule]", "1"}], ",", 
           RowBox[{"DefaultDuration", "\[Rule]", "1"}], ",", 
           RowBox[{"PausedTime", "\[Rule]", "0"}]}], "]"}], ",", 
         RowBox[{"Button", "[", 
          RowBox[{"\"\<reset\>\"", ",", 
           RowBox[{
            RowBox[{"trees", "=", 
             RowBox[{"Table", "[", 
              RowBox[{"0", ",", 
               RowBox[{"{", "100", "}"}], ",", 
               RowBox[{"{", "100", "}"}]}], "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"trees", "[", 
              RowBox[{"[", 
               RowBox[{
                RowBox[{"45", ";;", "55"}], ",", 
                RowBox[{"45", ";;", "55"}]}], "]"}], "]"}], "=", "1"}], 
            ";"}]}], "]"}]}], "}"}], "]"}], "&"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"trees", ",", 
       RowBox[{"ReplacePart", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", "100", "}"}], ",", 
           RowBox[{"{", "100", "}"}]}], "]"}], ",", 
         RowBox[{
          RowBox[{"Partition", "[", 
           RowBox[{
            RowBox[{"Flatten", "@", 
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"i", ",", "j"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"i", ",", "45", ",", "55"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"j", ",", "45", ",", "55"}], "}"}]}], "]"}]}], ",", 
            "2"}], "]"}], "\[Rule]", "1"}]}], "]"}]}], "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "None"}]}], "}"}], ",", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}], ",", 
   RowBox[{"TrackedSymbols", "\[RuleDelayed]", 
    RowBox[{"{", 
     RowBox[{"ignite", ",", "staylit", ",", "run", ",", "trees"}], "}"}]}]}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{
  3.35696210375764*^9, {3.3869543003895025`*^9, 3.386954342640256*^9}},
 CellID->87988515],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`ignite$$ = 0.7, $CellContext`run$$ = 
    10, $CellContext`staylit$$ = 0.45, $CellContext`trees$$ = CompressedData["

1:eJztljEOgzAQBL33k3wpT4jS5/9d4AyBRNDtORQzkoXsYkfns2Vuj9f9Ea21
5zIAAAAAAAAALkHEbiIpR6Vkio8CR3RHzOE5iwpFWubsWCcVili+Sk+R44tq
h/yKg0LqDUMcdsUQx4B2/GevKgx7Sxtyxa35OhC4LdMbUe04M1jrOFN4JXMl
+kk3d10HbW/+s3Xi8JaivlurTP2l9R7f9dUrdLTM1EcifzsyO//XltuivuCW
7BQ9fCrO7dhUqkvfHKUCAAAAAACAi/MG2D4GWw==
    "], Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`ignite$$], 0.7, "chance to catch on fire"}, 0.1, 
      0.9}, {{
       Hold[$CellContext`staylit$$], 0.45, "chance to stay on fire"}, 0.1, 
      0.9}, {
      Hold[$CellContext`run$$], 
      Dynamic[Row[{
         Animator[
          
          Dynamic[$CellContext`run$$, ($CellContext`iteration; \
$CellContext`run$$ = #)& ], {0, Infinity, 1}, 
          AppearanceElements -> {"PlayPauseButton"}, DisplayAllSteps -> True, 
          AnimationRepetitions -> 1, DefaultDuration -> 1, PausedTime -> 0], 
         Button[
         "reset", $CellContext`trees$$ = Table[0, {100}, {100}]; 
          Part[$CellContext`trees$$, 
             Span[45, 55], 
             Span[45, 55]] = 1; Null]}]& ]}, {{
       Hold[$CellContext`trees$$], CompressedData["
1:eJztzaENACAMAMHCJqzECA2++zsMCR6DuUte/8ia2SNinQAAAAB41y4PDw8P
AAAAAD7b1KwC6g==
       "]}}}, Typeset`size$$ = {400., {226., 230.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`ignite$839$$ = 0, $CellContext`staylit$840$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`ignite$$ = 0.7, $CellContext`run$$ = 
        Dynamic[Row[{
            Animator[
             
             Dynamic[$CellContext`run$$, ($CellContext`iteration; \
$CellContext`run$$ = #)& ], {0, Infinity, 1}, 
             AppearanceElements -> {"PlayPauseButton"}, DisplayAllSteps -> 
             True, AnimationRepetitions -> 1, DefaultDuration -> 1, 
             PausedTime -> 0], 
            Button[
            "reset", $CellContext`trees$$ = Table[0, {100}, {100}]; 
             Part[$CellContext`trees$$, 
                Span[45, 55], 
                Span[45, 55]] = 1; Null]}]& ], $CellContext`staylit$$ = 
        0.45, $CellContext`trees$$ = CompressedData["
1:eJztzaENACAMAMHCJqzECA2++zsMCR6DuUte/8ia2SNinQAAAAB41y4PDw8P
AAAAAD7b1KwC6g==
         "]}, "ControllerVariables" :> {
        Hold[$CellContext`ignite$$, $CellContext`ignite$839$$, 0], 
        Hold[$CellContext`staylit$$, $CellContext`staylit$840$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      DynamicModule[{}, 
        SeedRandom[1]; $CellContext`iteration := 
         Module[{}, Map[(Part[$CellContext`trees$$, 
                Apply[Sequence, #]] = 
              RandomChoice[{$CellContext`staylit$$, 
                  1 - $CellContext`staylit$$} -> {1, 2}]; Null)& , 
             Position[$CellContext`trees$$, 1]]; Map[(Do[
               Which[
                MemberQ[# + $CellContext`i, 
                 Alternatives[0, 101]], Null, Part[$CellContext`trees$$, 
                  Apply[Sequence, # + $CellContext`i]] == 0, 
                Part[$CellContext`trees$$, 
                  Apply[Sequence, # + $CellContext`i]] = 
                RandomChoice[{
                   1 - $CellContext`ignite$$, $CellContext`ignite$$} -> {0, 
                   1}]], {$CellContext`i, 
                DeleteCases[
                 Tuples[{-1, 0, 1}, 2], {0, 0}]}]; Null)& , 
             Position[$CellContext`trees$$, 1]]]; Dynamic[
          Graphics[
           Raster[
            Developer`ToPackedArray[
             ReplaceAll[$CellContext`trees$$, {
              0 -> {0., 0.6, 0.}, 1 -> {1., 0.2, 0.}, 
               2 -> {0.8, 0.8, 0.8}}]]], ImageSize -> 400, PlotLabel -> 
           Style[
             Column[{
               Row[{"not burned: ", 
                 NumberForm[
                  Round[
                   N[Count[
                    Flatten[$CellContext`trees$$], 0]/100], 0.01], {4, 2}, 
                  NumberPadding -> {" ", "0"}], "%"}], 
               Row[{"on fire:         ", 
                 NumberForm[
                  Round[
                   N[Count[
                    Flatten[$CellContext`trees$$], 1]/100], 0.01], {4, 2}, 
                  NumberPadding -> {" ", "0"}], "%"}], 
               Row[{"burned:       ", 
                 NumberForm[
                  Round[
                   N[Count[
                    Flatten[$CellContext`trees$$], 2]/100], 0.01], {4, 2}, 
                  NumberPadding -> {" ", "0"}], "%"}]}], "Label", 12], 
           PlotRange -> {{0, 100}, {0, 100}}]]], 
      "Specifications" :> {{{$CellContext`ignite$$, 0.7, 
          "chance to catch on fire"}, 0.1, 0.9, Appearance -> 
         "Labeled"}, {{$CellContext`staylit$$, 0.45, 
          "chance to stay on fire"}, 0.1, 0.9, Appearance -> 
         "Labeled"}, {$CellContext`run$$, 
         Dynamic[Row[{
            Animator[
             
             Dynamic[$CellContext`run$$, ($CellContext`iteration; \
$CellContext`run$$ = #)& ], {0, Infinity, 1}, 
             AppearanceElements -> {"PlayPauseButton"}, DisplayAllSteps -> 
             True, AnimationRepetitions -> 1, DefaultDuration -> 1, 
             PausedTime -> 0], 
            Button[
            "reset", $CellContext`trees$$ = Table[0, {100}, {100}]; 
             Part[$CellContext`trees$$, 
                Span[45, 55], 
                Span[45, 55]] = 1; 
             Null]}]& ]}, {{$CellContext`trees$$, CompressedData["
1:eJztzaENACAMAMHCJqzECA2++zsMCR6DuUte/8ia2SNinQAAAAB41y4PDw8P
AAAAAD7b1KwC6g==
          "]}, ControlType -> None}}, 
      "Options" :> {
       TrackedSymbols :> {$CellContext`ignite$$, $CellContext`staylit$$, \
$CellContext`run$$, $CellContext`trees$$}}, 
      "DefaultOptions" :> {ControllerLinking -> True}],
     ImageSizeCache->{442., {299.375, 304.625}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`iteration := 
       Module[{}, Map[(Part[FE`trees$$36, 
              Apply[Sequence, #]] = 
            RandomChoice[{FE`staylit$$36, 1 - FE`staylit$$36} -> {1, 2}]; 
           Null)& , 
           Position[FE`trees$$36, 1]]; Map[(Do[
             Which[
              MemberQ[# + $CellContext`i, 
               Alternatives[0, 101]], Null, Part[FE`trees$$36, 
                Apply[Sequence, # + $CellContext`i]] == 0, 
              Part[FE`trees$$36, 
                Apply[Sequence, # + $CellContext`i]] = 
              RandomChoice[{1 - FE`ignite$$36, FE`ignite$$36} -> {0, 
                 1}]], {$CellContext`i, 
              DeleteCases[
               Tuples[{-1, 0, 1}, 2], {0, 0}]}]; Null)& , 
           Position[FE`trees$$36, 1]]], FE`trees$$36 = CompressedData["
1:eJztzaENACAMAMHCJqzECA2++zsMCR6DuUte/8ia2SNinQAAAAB41y4PDw8P
AAAAAD7b1KwC6g==
        "], FE`staylit$$36 = 0.45, FE`ignite$$36 = 0.7}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellID->280783407]
}, {2}]]
}, Open  ]],

Cell[CellGroupData[{

Cell["THIS NOTEBOOK IS THE SOURCE CODE FROM", "Text",
 CellFrame->{{0, 0}, {0, 1}},
 CellMargins->{{48, 10}, {4, 28}},
 CellGroupingRules->{"SectionGrouping", 25},
 CellFrameMargins->{{48, 48}, {6, 5}},
 CellFrameColor->RGBColor[0.691905, 0.790311, 0.300252],
 FontFamily->"Helvetica",
 FontSize->10,
 FontWeight->"Bold",
 FontColor->RGBColor[0.691905, 0.790311, 0.300252]],

Cell[TextData[{
 "\"",
 ButtonBox["Probabilistic Forest Fire Model",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/ProbabilisticForestFireModel/"], 
    None},
  ButtonNote->
   "http://demonstrations.wolfram.com/ProbabilisticForestFireModel/"],
 "\"",
 " from ",
 ButtonBox["The Wolfram Demonstrations Project",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/"], None},
  ButtonNote->"http://demonstrations.wolfram.com/"],
 "\[ParagraphSeparator]\[NonBreakingSpace]",
 ButtonBox["http://demonstrations.wolfram.com/ProbabilisticForestFireModel/",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/ProbabilisticForestFireModel/"], 
    None},
  ButtonNote->
   "http://demonstrations.wolfram.com/ProbabilisticForestFireModel/"]
}], "Text",
 CellMargins->{{48, Inherited}, {0, Inherited}},
 FontFamily->"Verdana",
 FontSize->10,
 FontColor->GrayLevel[0.5]]
}, Open  ]],

Cell[CellGroupData[{

Cell[" ", "Text",
 CellFrame->{{0, 0}, {0, 1}},
 CellMargins->{{48, 10}, {4, 28}},
 CellGroupingRules->{"SectionGrouping", 25},
 CellFrameMargins->{{48, 48}, {6, 5}},
 CellFrameColor->RGBColor[0.691905, 0.790311, 0.300252],
 FontFamily->"Helvetica",
 FontSize->10,
 FontWeight->"Bold",
 FontColor->RGBColor[0.691905, 0.790311, 0.300252]],

Cell["Contributed by: Rob Morris", "Text",
 CellDingbat->"\[FilledSmallSquare]",
 CellMargins->{{66, 48}, {2, 4}},
 FontFamily->"Verdana",
 FontSize->10,
 FontColor->GrayLevel[0.6],
 CellID->31567231],

Cell["Additional Contributions by: Carl Woll and Lou D'Andria", "Text",
 CellDingbat->"\[FilledSmallSquare]",
 CellMargins->{{66, 48}, {2, 4}},
 FontFamily->"Verdana",
 FontSize->10,
 FontColor->GrayLevel[0.6],
 CellID->410248545],

Cell[TextData[{
 "A full-function Wolfram ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 6 system is required to edit or run this notebook.\[IndentingNewLine](",
 StyleBox["Mathematica Player",
  FontSlant->"Italic"],
 " runs only Demonstrations published on this site.)\n",
 StyleBox[ButtonBox["GET WOLFRAM MATHEMATICA 6 \[RightGuillemet]",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/products/mathematica/"], None},
  ButtonNote->"http://www.wolfram.com/products/mathematica/"],
  FontFamily->"Helvetica",
  FontWeight->"Bold",
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0.42, 0]]
}], "Text",
 CellFrame->True,
 CellMargins->{{48, 68}, {8, 28}},
 CellFrameMargins->12,
 CellFrameColor->RGBColor[0.865507, 0.90634, 0.680751],
 CellChangeTimes->{3.3750111182355957`*^9},
 ParagraphSpacing->{1., 1.},
 FontFamily->"Verdana",
 FontSize->10,
 FontColor->GrayLevel[0.411765],
 Background->RGBColor[0.986023, 0.991363, 0.969818]],

Cell[TextData[{
 "\[Copyright] ",
 StyleBox[ButtonBox["The Wolfram Demonstrations Project & Contributors",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/"], None},
  ButtonNote->"http://demonstrations.wolfram.com/"],
  FontColor->GrayLevel[0.6]],
 "\[ThickSpace]\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
 StyleBox[ButtonBox["Terms of Use",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/termsofuse.html"], None},
  ButtonNote->"http://demonstrations.wolfram.com/termsofuse.html"],
  FontColor->GrayLevel[0.6]],
 "\[ThickSpace]\[ThickSpace]\[ThickSpace]|\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
 StyleBox[ButtonBox["Make a new version of this Demonstration \
\[RightGuillemet]",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/participate/upload.jsp?id=\
ProbabilisticForestFireModel"], None},
  ButtonNote->None],
  FontColor->GrayLevel[0.6]]
}], "Text",
 CellFrame->{{0, 0}, {0, 0.5}},
 CellMargins->{{48, 10}, {20, 50}},
 CellFrameMargins->{{6, 0}, {6, 6}},
 CellFrameColor->GrayLevel[0.6],
 FontFamily->"Verdana",
 FontSize->9,
 FontColor->GrayLevel[0.6]]
}, Open  ]]
},
ClosingSaveDialog->False,
Editable->True,
ScreenStyleEnvironment->"Working",
WindowSize->{710, 650},
WindowMargins->{{Inherited, Inherited}, {Inherited, 0}},
WindowElements->{
 "StatusArea", "MemoryMonitor", "MagnificationPopUp", "VerticalScrollBar", 
  "MenuBar"},
WindowTitle->"Probabilistic Forest Fire Model - Source",
DockedCells->{},
CellContext->Notebook,
FrontEndVersion->"6.0 for Mac OS X x86 (32-bit) (May 22, 2007)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 223, 4, 67, "Section"],
Cell[CellGroupData[{
Cell[838, 31, 11027, 266, 778, "Input",
 CellID->87988515],
Cell[11868, 299, 7719, 167, 622, "Output",
 CellID->280783407]
}, {2}]]
}, Open  ]],
Cell[CellGroupData[{
Cell[19633, 472, 373, 9, 50, "Text",
 CellGroupingRules->{"SectionGrouping", 25}],
Cell[20009, 483, 966, 28, 34, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[21012, 516, 337, 9, 50, "Text",
 CellGroupingRules->{"SectionGrouping", 25}],
Cell[21352, 527, 200, 6, 18, "Text",
 CellID->31567231],
Cell[21555, 535, 230, 6, 18, "Text",
 CellID->410248545],
Cell[21788, 543, 967, 27, 114, "Text"],
Cell[22758, 572, 1204, 33, 88, "Text"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
